Skip to contents

Extracts luminance information from a specified colorspace and returns the appropriate channel.

Usage

img_luminosity(image, method = "grayscale", file = NULL, overwrite = FALSE)

Arguments

image

character or magick-image. Image to extract information from.

method

character. The method used to calculate luminosity/brightness. Options are "greyscale" or "grayscale" to get a greyscale version of an RGB image, "LAB" to extract the lightness (L) channel from a LAB colorspace, "HSV" to extract the value (V) channel from a HVS colorspace, "YCbCr" for the luminance channel (Y) from a YCbCr color space, or "YIQ" for the luma (Y) channel in YIQ colorspace. YCbCr and YIQ produce the same luminosity values, despite being different colorspaces.

file

character. File path to the output image.

overwrite

logical. If overwriting files is allowed.

Value

a magick image.