Skip to contents

Calculates the relative similarity of images and returns perceptual hash values characterizing similarity between images. Returns a dataframe with the index or names (if using a named list for match) of match images and the p-hash. p-hash values range from zero to infinity, with zero being identical images.

Usage

img_match(image, match)

Arguments

image

character or magick-image. The image to be examined.

match

list. Images to be compared to image for matches.

Value

a data frame.