Calculates the relative similarity of images and returns perceptual hash values
characterizing similarity between images. Returns a dataframe with the index or
names (if using a named list for match) of match images and the p-hash. p-hash
values range from zero to infinity, with zero being identical images.