Flattens MegaDetector/SpeciesNet JSON files to a table format. Data is split by detection, with images potentially having more than one row of data if more than one detection was found. Images with no detections will have only one record here, with no detection (bbox) information.
Arguments
- json
character vector or nested list object from
jsonlite::read_json(). The JSON file or loaded JSON data to filter on.- map_names
boolean. If MegaDetector and SpeciesNet names should be mapped from numeric values to the values provided in the
detection_categoriesandclassification_categoriestags. These are typically gross (human, animal, vehicle) and taxonomic classifications respectively.